import {getAllRoleList} from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import {h} from "vue";
import {Input, Select, Tag} from "ant-design-vue";
import { Switch } from 'ant-design-vue';
import {useMessage} from "@/hooks/web/useMessage";
import {changeFlagApi} from "@/api/system/user/user";
import {DescItem} from "@/components/Description";
import {uploadApi} from "@/api/sys/upload"; // 引入开关组件
type CheckedType = boolean | string | number;

/**主页面列表 表头*/
export const columns: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'apiName',
    width: 150,
    slots: { customRender: 'apiName' },
  },
  {
    title: '权属工作组',
    dataIndex: 'workGroup',
    width: 150,
  },
  {
    title: '模式',
    dataIndex: 'mode',
    width: 150,
  },
  {
    title: '创建时间',
    dataIndex: 'createDate',
    width: 150,
  },
  {
    title: '更新时间',
    dataIndex: 'updateDate',
    width: 150,
  },
  {
    title: '拥有者',
    dataIndex: 'holder',
    width: 150,
  },
];
/**主页面搜索 表单*/
export const searchFormSchema: FormSchema[] = [
  {
    field: 'apiName',
    label: '名称',
    component: 'Input',
    componentProps: {
      placeholder: '请输入名称',
    },
    colProps: { span: 6 },
  },
];
/**新建API 表单*/
export const createAPIFormSchema: FormSchema[] = [
  {
    field: 'path',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'apiName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
  },
  {
    field: 'documentName',
    label: '文件名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入文件名称',
      },
    ],
    componentProps: {
      placeholder: '请输入文件名称',
    },
  },
  {
    field: 'documentType',
    label: '文件类型',
    component: 'Input',
    defaultValue: 'API',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      style: { border: 'none' },
      readonly: true,
      placeholder: '请输入文件类型',
    },
  },
  {
    field: 'catalogOwnershipMode',
    label: '目录权属模式',
    component: 'Input',
    defaultValue: '本级定义',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      style: { border: 'none' },
      readonly: true,
      placeholder: '请输入目录权属模式',
    },
  },
  {
    field: 'workGroup',
    label: '权属工作组',
    component: 'Input',
    defaultValue: '默认工作组',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      style: { border: 'none' },
      readonly: true,
      placeholder: '请输入权属工作组',
    },
  },
];
/**新建文件夹 表单*/
export const createDocumentFormSchema: FormSchema[] = [
  {
    field: 'path',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'apiName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
  },
  {
    field: 'documentName',
    label: '文件夹名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入文件夹名称',
      },
    ],
    componentProps: {
      placeholder: '请输入文件夹名称',
    },
  },
];
/**导入 表单*/
export const importApiFormSchema: FormSchema[] = [
  {
    field: 'importType',
    component: 'RadioGroup',
    label: '导入类型',
    colProps: { lg: 24, md: 24 },
    labelWidth: 150,
    componentProps: {
      defaultValue:'1',
      options: [
        {
          label: '同集群导入',
          value: '1',
        },
        {
          label: '其他集群导入',
          value: '2',
        },
      ],
    },
  },
  {
    field: 'path',
    label: '导入至',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    labelWidth: 150,
    componentProps: {
      fieldNames: {
        label: 'apiName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'file',
    component: 'Upload',
    label: '导入文件选择',
    componentProps: {
      api: uploadApi,
    },
    labelWidth: 150,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'agreement',
    component: 'RadioGroup',
    label: '文件重名',
    colProps: { lg: 24, md: 24 },
    labelWidth: 150,
    componentProps: {
      defaultValue:'3',
      options: [
        {
          label: '全部放弃',
          value: '1',
        },
        {
          label: '全部替换',
          value: '2',
        },
        {
          label: '自动重命名',
          value: '3',
        },
      ],
    },
  },
];
/**移动 表单*/
export const moveFormSchema: any[] = [
  {
    field: 'path',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'apiName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
]
/**复制 表单*/
export const copyFormSchema: any[] = [
  {
    field: 'path',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'apiName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
]
/**重命名 表单*/
export const resetNameFormSchema: FormSchema[] = [
  {
    field: 'apiName',
    label: '名称',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入名称',
      },
    ],
    componentProps: {
      placeholder: '请输入名称',
    },
    colProps: { lg: 24, md: 24 },
  },
];
/**apiDoc列表 表头*/
export const apiDocColumns: BasicColumn[] = [
 {
    "title": "参数code",
    "dataIndex": "parameterCode",
    "width": 120
  },
  {
    "title": "参数位置",
    "dataIndex": "parameterPosition",
    "width": 120
  },
  {
    "title": "Xpath",
    "dataIndex": "xpath",
    "width": 120
  },
  {
    "title": "参数类型",
    "dataIndex": "parameterType",
    "width": 120
  },
  {
    "title": "注释",
    "dataIndex": "annotation",
    "width": 120
  },
  {
    "title": "是否必填",
    "dataIndex": "isRequired",
    "width": 120
  },
  {
    "title": "参数值",
    "dataIndex": "parameterValue",
    "width": 120,
    "editable": true,
    "edit": true
  }
];



/**基础公共代码表单*/
export const detailSchema: FormSchema[] = [
  {
    field: '',
    label: '属性',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'standardPath',
    label: '标准路径',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准路径',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
  {
    field: 'standardNumber',
    label: '标准编号',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准编号',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准编号',
    },
  },
  {
    field: 'standardChineseName',
    label: '标准中文名称',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准中文名称',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准中文名称',
    },
  },
  {
    field: 'standardSource',
    label: '标准来源',
    component: 'Select',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请选择标准来源',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
      options:[
        {
          label:'国际标准',
          value:'1'
        },
        {
          label:'国家标准',
          value:'2'
        },
        {
          label:'行业标准',
          value:'3'
        },
        {
          label:'行业实践',
          value:'4'
        },
        {
          label:'监管规定(人行)',
          value:'5'
        },
        {
          label:'监管规定(银监)',
          value:'6'
        },
        {
          label:'行内发文',
          value:'7'
        },
        {
          label:'行内协商一致',
          value:'8'
        },
      ],
      placeholder: '请选择标准来源',
    },
  },
  {
    field: 'businessDefinition',
    label: '业务定义',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入业务定义',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
  {
    field: 'definitionBasis',
    label: '定义依据',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入定义依据',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
];
/**详情页列表 表头*/
export const detailColumns: BasicColumn[] = [
  {
    title: '代码值',
    dataIndex: 'codeValue',
    width: 150
  },
  {
    title: '代码含义',
    dataIndex: 'codeMeaning',
    width: 150
  },
  {
    title: '说明',
    dataIndex: 'description',
    width: 150
  },
  {
    title: '修改人',
    dataIndex: 'updateBy',
    width: 150
  },
  {
    title: '修改时间',
    dataIndex: 'updateDate',
    width: 150
  },
  {
    title: '源系统码值',
    dataIndex: 'sourceSystemCodeValue',
    width: 150
  }
];
/**详情页列表 表单*/
export const detailFormSchema: FormSchema[] = [
  {
    field: 'codeValue',
    label: '代码值',
    component: 'Input',
    componentProps: {
      placeholder: '请输入代码值',
    },
    colProps: { span: 6 },
  },
  {
    field: 'codeMeaning',
    label: '代码含义',
    component: 'Input',
    componentProps: {
      placeholder: '请输入代码含义',
    },
    colProps: { span: 6 },
  },
  {
    field: 'sourceSystemCodeValue',
    label: '源系统码值',
    component: 'Input',
    componentProps: {
      placeholder: '请输入源系统码值',
    },
    colProps: { span: 6 },
  },
];
/**编辑公共代码 表单1*/
export const editStandardsDetailFormSchema: FormSchema[] = [
  {
    field: '',
    label: '属性',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'standardPath',
    label: '标准路径',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准路径',
      },
    ],
    componentProps: {
      placeholder: '-',
    },
  },
  {
    field: 'standardNumber',
    label: '标准编号',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准编号',
      },
    ],
    componentProps: {
      placeholder: '请输入标准编号',
    },
  },
  {
    field: 'standardChineseName',
    label: '标准中文名称',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准中文名称',
      },
    ],
    componentProps: {
      placeholder: '请输入标准中文名称',
    },
  },
  {
    field: 'standardSource',
    label: '标准来源',
    component: 'Select',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请选择标准来源',
      },
    ],
    componentProps: {
      options:[
        {
          label:'国际标准',
          value:'1'
        },
        {
          label:'国家标准',
          value:'2'
        },
        {
          label:'行业标准',
          value:'3'
        },
        {
          label:'行业实践',
          value:'4'
        },
        {
          label:'监管规定(人行)',
          value:'5'
        },
        {
          label:'监管规定(银监)',
          value:'6'
        },
        {
          label:'行内发文',
          value:'7'
        },
        {
          label:'行内协商一致',
          value:'8'
        },
      ],
      placeholder: '请选择标准来源',
    },
  },
  {
    field: 'businessDefinition',
    label: '业务定义',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入业务定义',
      },
    ],
    componentProps: {
      placeholder: '-',
    },
  },
  {
    field: 'definitionBasis',
    label: '定义依据',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入定义依据',
      },
    ],
    componentProps: {
      placeholder: '-',
    },
  },
];
/**编辑公共代码 表单2*/
export const addValueFormSchema: FormSchema[] = [
  {
    field: 'codeValue',
    label: '代码值',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: '请输入代码值',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'codeMeaning',
    label: '代码含义',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: '请输入代码含义',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'description',
    label: '说明',
    component: 'Input',
    componentProps: {
      placeholder: '请输入说明',
    },
    colProps: { lg: 24, md: 24 },
  },
];
/**编辑公共代码 表单3*/
export const addValueSearchSchema: FormSchema[] = [
  {
    field: 'sourceSystem',
    label: '源系统',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: '请输入源系统',
    },
    colProps: { span: 8 },
  },
  {
    field: 'sourceSystemCodeValue',
    label: '源系统码值',
    component: 'Input',
    componentProps: {
      placeholder: '请输入源系统码值',
    },
    colProps: { span: 8 },
  },
];
/**编辑公共代码 表单4*/
export const editPublicCodeSchema: FormSchema[] = [
  {
    field: 'codeValue',
    label: '代码值',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: '请输入代码值',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'codeMeaning',
    label: '代码含义',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: '请输入代码含义',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'description',
    label: '说明',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: '请输入说明',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'sourceSystemCodeValue',
    label: '源系统码值',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: '请输入源系统码值',
    },
    colProps: { lg: 24, md: 24 },
  },
];
/**详情公共代码 表单5*/
export const detailPublicCodeSchema: FormSchema[] = [
  {
    field: 'codeValue',
    label: '代码值',
    component: 'Input',
    required: true,
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入代码值',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'codeMeaning',
    label: '代码含义',
    component: 'Input',
    required: true,
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入代码含义',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'description',
    label: '说明',
    component: 'Input',
    required: true,
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入说明',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'sourceSystemCodeValue',
    label: '源系统码值',
    component: 'Input',
    required: true,
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入源系统码值',
    },
    colProps: { lg: 24, md: 24 },
  },
];
/**编辑公共代码 列表表头*/
export const addValueColumns: BasicColumn[] = [
  {
    title: '源系统',
    dataIndex: 'sourceSystem',
    width: 150
  },
  {
    title: '源系统码值',
    dataIndex: 'sourceSystemCodeValue',
    width: 150
  },
];
/**版本对比 表单*/
export const contrastSchema: FormSchema[] = [
  {
    field: '',
    label: 'API模式',
    component: 'Input',
    defaultValue: '向导...',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
    },
    colProps: { lg: 6, md: 6 },
  },
  {
    field: 'standardPath',
    label: '数据源',
    component: 'Input',
    defaultValue: '某能源集团人力...',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
    },
    colProps: { lg: 6, md: 6 },
  },
  {
    field: 'standardNumber',
    label: '数据库',
    component: 'Input',
    defaultValue: 'dws',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
    },
    colProps: { lg: 6, md: 6 },
  },
  {
    field: 'standardChineseName',
    label: '数据表',
    component: 'Input',
    defaultValue: 'dws_tb_employee',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
    },
    colProps: { lg: 6, md: 6 },
  },
];
/**版本对比 列表1*/
export const contrastTableColumns1: BasicColumn[] = [
  {
    title: '参数code',
    dataIndex: 'parameterCode',
    width: 150
  },
  {
    title: '参数名称',
    dataIndex: 'parameterName',
    width: 150
  },
  {
    title: '参数类型',
    dataIndex: 'parameterType',
    width: 150
  },
  {
    title: '注释',
    dataIndex: 'comment',
    width: 150
  },
  {
    title: '是否必填',
    dataIndex: 'required',
    width: 150
  },
  {
    title: '参数值',
    dataIndex: 'parameterValue',
    width: 150
  },
];
/**版本对比 列表2*/
export const contrastTableColumns2: BasicColumn[] = [
  {
    title: '参数code',
    dataIndex: 'parameterCode',
    width: 150
  },
  {
    title: '参数名称',
    dataIndex: 'parameterName',
    width: 150
  },
  {
    title: '参数类型',
    dataIndex: 'parameterType',
    width: 150
  },
  {
    title: '是否必填',
    dataIndex: 'required',
    width: 150
  },
  {
    title: '默认值',
    dataIndex: 'defaultValue',
    width: 150
  },
];
/**版本对比 列表3*/
export const contrastTableColumns3: BasicColumn[] = [
  {
    title: '参数code',
    dataIndex: 'parameterCode',
    width: 150
  },
  {
    title: '参数名称',
    dataIndex: 'parameterName',
    width: 150
  },
  {
    title: '注释',
    dataIndex: 'comment',
    width: 150
  },
];
/**版本列表 回滚表单*/
export const returnVersionFormSchema: FormSchema[] = [
  {
    field: 'historyVersion',
    label: '选择历史版本',
    component: 'Select',
    rules: [
      {
        required: true,
        message: '请选择历史版本',
      },
    ],
    componentProps: {
      options: [
        {
          label: 'V1',
          value: 'V1',
        },
        {
          label: 'V2',
          value: 'V2',
        },
        {
          label: 'V3',
          value: 'V3',
        },
      ],
      placeholder: '请选择历史版本',
    },
    colProps: { lg: 24, md: 24 },
  },
];



